/*
 * Project name:
     DIGI POT 2 click
 * Copyright:
     (c) Mikroelektronika, 2016.
 * Revision History
     20160622 (AM);
       - initial release;
 * Description:
     This program demonstrates the usage of Digital Potentiometer 2 Board (TPL0501).
     Voltage derived from W pin is read by MCU's ADC (AN2). Scaled value is then displayed at PORTD LEDs.
     User can increase or decrease resitance by pressing buttons RB2 and RB3. It's all happening in an endless loop.
 * Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156F.pdf
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     ext. modules:    Digi Pot 2 click
                      http://www.mikroe.com/click/digipot2/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 * NOTES:
     - Digi Pot 2 click must be connected on mikroBUS socket 1.
     - Connect Digi Pot 2 click L to GND, H to VCC and W to RB0 pin.
     - Don't use pull-up(down) resistor at RB0 pin.
     - Place Button Press Level switch in upper position for PORTD
         and pull down PORTD pins 0 and 1 (PortD three-state switch).
     - Turn SPI lines on SW13.
     - Turn ON TFT backlight on SW11.
*/

#include "resources.h"

sbit DigPot_CS at LATC2_bit;
sbit DigPot_CS_Direction at TRISC2_bit;

unsigned int adc_value;
unsigned short counter;

/**************************************************************************************************
* Draw Screen
**************************************************************************************************/
void DrawScr(){
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("DigiPot 2 click  TEST", 75, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
}

/**************************************************************************************************
* Main Init
**************************************************************************************************/
void InitMain() {
  AD1PCFG = 0xFFFE;                // Configure AN pins as digital I/O, RBO as analog
  JTAGEN_bit = 0;                  // Disable JTAG

  DigPot_CS_Direction = 0;
  TRISD0_bit = 1;
  TRISD1_bit = 1;
  TRISB0_bit = 1;

  ADC1_Init();

  DigPot_CS = 1;

  // Initialize SPI module
  SPI3_Init_Advanced(_SPI_MASTER, _SPI_8_BIT, 80, _SPI_SS_DISABLE, _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_LOW, _SPI_IDLE_2_ACTIVE);

  adc_value = 0;
  counter = 200;

  TFT_Init_ILI9341_8bit(320, 240);
}

/**************************************************************************************************
* Write Graph
**************************************************************************************************/
void Wr_Graph(int value){
static int oldvalue = 0;

  if (value < oldvalue){
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
    TFT_Rectangle(150, 200 - oldvalue/10, 170, 200 - value/10);
  }
  else{
    TFT_Set_Pen(CL_RED, 1);
    TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
    TFT_Rectangle(150, 200 - value/10, 170, 200 - oldvalue/10);
  }
  oldvalue = value;
}

/**************************************************************************************************
* Main Function
**************************************************************************************************/
void main() {

  InitMain();                            // Perform main initialization
  Delay_ms(100);

  DrawScr();
  TFT_Write_Text("Press buttons RD0 and RD1 to change output", 20, 50);
  TFT_Set_Pen(CL_RED, 1);

  while (1) {                            // Endless loop

    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPI3_Write(0);
    SPI3_Write(counter);

    SPI3_Write(0x20);
    SPI3_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip

    adc_value = ADC1_Get_Sample(0);      // Get 10-bit results of AD conversion

    Wr_Graph(adc_value);

    if (RD1_bit) {                       // Press RD1 to decrease resistance between W and L
      counter ++;
      if (counter == 255)
        counter = 127;
    }
    if (RD0_bit) {                       // Press RD0 to increase resistance between W and L
      counter --;
      if (counter == 127)
        counter = 255;
    }
    Delay_ms(50);                        // Delay for debouncing
  }
}